@@ -3,12 +3,12 @@ import requests
 from .config import HUB_API_ROOT
 from .hub_logger import HUBLogger
 from .utils.general import colorstr, emojis
+from .yolov5_wrapper import YOLOv5Wrapper as YOLOv5
 
 PREFIX = colorstr('Ultralytics: ')
 
 
 class Trainer:
-    from .yolov5_wrapper import YOLOv5Wrapper as YOLOv5
 
     def __init__(self, model_id, auth):
         self.auth = auth
@@ -52,7 +52,7 @@ class Trainer:
             # sys.exit(141)  # TODO: keep this 141 sys exit error code?
 
     def _connect_callbacks(self):
-        callback_handler = self.YOLOv5.new_callback_handler()
+        callback_handler = YOLOv5.new_callback_handler()
         hub_logger = HUBLogger(self.model_id, self.auth)
         callback_handler.register_action("on_model_save", "HUB", hub_logger.on_model_save)
         callback_handler.register_action("on_train_end", "HUB", hub_logger.on_train_end)
@@ -61,4 +61,4 @@ class Trainer:
     def start(self):
         # Force sandbox key
         self.model["sandbox"] = self.model["project"]
-        self.YOLOv5.train(self.callbacks, **self.model)
+        YOLOv5.train(self.callbacks, **self.model)
